@@ -149,12 +149,12 @@ class GourdTcp(asyncore.dispatcher, CallBackMgr):
         while self._map:
             poll_fun(constants.LOOP_TIMEOUT, self._map)
             # after_poll_func_list
-            for func in self.server.after_poll_func_list:
+            for func in self.after_poll_func_list:
                 try:
                     func()
                 except Exception, e:
-                    self.server.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
-                                             func.__name__, e, __import__('traceback').format_exc())
+                    self.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                      func.__name__, e, __import__('traceback').format_exc())
 
 
 class GourdTcpRequestHandler(asynchat.async_chat):
@@ -244,12 +244,12 @@ class GourdUdp(asyncore.dispatcher, CallBackMgr):
         while self._map:
             poll_fun(constants.LOOP_TIMEOUT, self._map)
             # after_poll_func_list
-            for func in self.server.after_poll_func_list:
+            for func in self.after_poll_func_list:
                 try:
                     func()
                 except Exception, e:
-                    self.server.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
-                                             func.__name__, e, __import__('traceback').format_exc())
+                    self.logger.error('after_poll_func_list raise exception. func: %s, e: %s, traceback: %s',
+                                      func.__name__, e, __import__('traceback').format_exc())
 
 
 class GourdUdpRequestHandler(object):
